@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/gtk.c,v 1.149 2004/12/17 17:00:40 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/gtk.c,v 1.151 2005/01/03 21:49:30 richb Exp $
  *
  *  Copyright (c) 1987-2004 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -1120,7 +1120,7 @@ create_kframe()
 
     X->kframe = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     g_object_set_data(G_OBJECT(X->kframe), "kframe", X->kframe);
-    gtk_window_set_resizable(GTK_WINDOW(X->kframe), FALSE);
+    gtk_window_set_resizable(GTK_WINDOW(X->kframe), TRUE);
 
     g_signal_connect(G_OBJECT(X->kframe), "delete_event",
                        G_CALLBACK(quit_cb), NULL);
@@ -1795,12 +1795,12 @@ check_vals(int n, int keyval, int state,
 {
     int i, j;
 
-    state = state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK);
+    state = state & (GDK_CONTROL_MASK | GDK_MOD1_MASK);
     for (i = 0; i < n; i++) {
         j = 0;
         while (buttons[i].value[j] != 0) {
             if (buttons[i].value[j] == keyval) {
-                if (buttons[i].mods[j] == state) {
+                if ((buttons[i].mods[j] & ~GDK_SHIFT_MASK) == state) {
                     button_proc(GTK_BUTTON(gtk_buttons[i]), NULL);
                     return(TRUE);
                 }
